#
# spec file for package nodejs
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nodejs
Version:        4.2.1
Release:        2
Summary:        Evented I/O for V8 JavaScript
License:        MIT
Group:          Development/Languages/NodeJS
Url:            http://www.nodejs.org
Source:         http://nodejs.org/dist/v%{version}/node-v%{version}.tar.xz
Patch3:         support-arm64-build.patch
Patch5:         nodejs-lib64path.patch
Patch6:         nodejs-libpath.patch
# PATCH-FIX-UPSTREAM use custom addon.gypi by default instead of downloading node source
Patch7:         node-gyp-addon-gypi.patch
# PATCH-FIX-UPSTREAM enable FIPS only when configured with it
Patch8:         nodejs-no-fips.patch
BuildRequires:  curl
BuildRequires:  fdupes
BuildRequires:  gcc-c++
%if 0%{?suse_version}
BuildRequires:  libopenssl-devel
%else
BuildRequires:  openssl-devel
%endif
#BuildRequires:  pkg-config
BuildRequires:  procps
BuildRequires:  python
BuildRequires:  xz
BuildRequires:  zlib-devel

#we need ABI virtual provides where SONAMEs aren't enough/not present so deps
#break when binary compatibility is broken
%global nodejs_abi 4.0
Provides:       nodejs(abi) = %{nodejs_abi}

#this corresponds to the "engine" requirement in package.json
Provides:       nodejs(engine) = %{version}

#building nodejs makes sense only on v8 archs
ExclusiveArch:  %{ix86} x86_64 armv7hl aarch64 ppc ppc64 ppc64le s390x
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Node.js is a JavaScript runtime built on Chrome's V8 JavaScript engine.
Node.js uses an event-driven, non-blocking I/O model that makes it 
lightweight and efficient. Node.js' package ecosystem, npm, is the largest
ecosystem of open source libraries in the world.

%package devel
Summary:        Files needed for development of NodeJS platforms
Group:          Development/Languages/NodeJS
Requires:       %{name} = %{version}

%description devel
This package provides development headers for Node.js.

%package docs
Summary:        Node.js API documentation
Group:          Documentation/Other
%if 0%{?suse_version} >= 1200
# using noarch subpackage seems to break debuginfo on older releases
BuildArch:      noarch
%endif

%description docs
The API documentation for the Node.js JavaScript runtime.

%package npm
Summary:        Package manager for Node.js (Bundled)
Group:          Development/Languages/NodeJS
Requires:       %{name} = %{version}
Provides:       npm = 2.14.7
Obsoletes:      npm < 2.14.7
Provides:       npm(npm) = 2.14.7
Conflicts:      otherproviders(npm(npm))

%description npm
A package manager for Node.js, bundled in nodejs.

%prep
%setup -q -n node-v%{version}
#%%patch3 -p1
%if %{_lib} == "lib64"
%patch5 -p1
%else
%patch6 -p1
%endif
%patch7 -p1
#%%patch8 -p1
# Make sure nothing gets included from bundled deps:
# We only delete the source and header files, because
# the remaining build scripts are still used.
###for dir in v8 openssl zlib; do

for dir in openssl zlib; do
  find deps/$dir -name *.[ch] -delete
done

%build
# percent-configure pulls in something that confuses node's configure
# script, so we'll do it thus:
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
./configure \
    --prefix=%{_prefix} \
    --shared-openssl \
    --shared-zlib \
%ifarch aarch64
    --dest-cpu=arm64 \
%endif
%ifarch s390x
    --dest-cpu=s390x \
%endif
%ifnarch aarch64 ppc ppc64 ppc64le s390x
    --gdb \
%endif
    --without-dtrace

%ifarch aarch64
make DESTCPU=arm64
%else
%ifarch s390x
make DESTCPU=s390x
%else
make -j12 %{?_smp_mflags}
%endif
%endif

%install
make install DESTDIR=%{buildroot} %{?_smp_mflags}
rm -rf %{buildroot}%{_datadir}/doc/node

# npm man page
install -m 644 deps/npm/man/man1/npm.1 %{buildroot}%{_mandir}/man1

#node-gyp needs common.gypi too
mkdir -p %{buildroot}%{_datadir}/node
install -m 644 common.gypi %{buildroot}%{_datadir}/node

# install addon-rpm.gypi
install -m 644 addon-rpm.gypi %{buildroot}%{_datadir}/node

# Documentation
install -d %{buildroot}%{_docdir}/%{name}
cp -r doc/api %{buildroot}%{_docdir}/%{name}/

# Own nodejs_sitelib
install -d %{buildroot}%{_libexecdir}/node_modules

# clean
# file duplicates
%fdupes %{buildroot}%{_libdir}/node_modules/npm/
%fdupes %{buildroot}%{_includedir}/node
# hidden files
find %{buildroot}%{_libdir}/node_modules/npm -name ".*" -delete
# windows stuff
find %{buildroot}%{_libdir}/node_modules/npm -name "*.bat" -delete
find %{buildroot}%{_libdir}/node_modules/npm -name "*.cmd" -delete
# build stuff
find %{buildroot}%{_libdir}/node_modules/npm -name "Makefile" -delete
rm -rf %{buildroot}%{_libdir}/node_modules/npm/{test,scripts}
find %{buildroot}%{_libdir}/node_modules/npm/node_modules -name "*.sh" -delete
find %{buildroot}%{_libdir}/node_modules/npm -name "src" -print0 | xargs -0 rm -rf --
# remove examples/tests/benchmark stuff
find %{buildroot}%{_libdir}/node_modules/npm/node_modules -name "example*" -print0 | xargs -0 rm -rf --
find %{buildroot}%{_libdir}/node_modules/npm/node_modules -name "test*" -print0 | xargs -0 rm -rf --
find %{buildroot}%{_libdir}/node_modules/npm/node_modules -name "*_test.*" -delete
find %{buildroot}%{_libdir}/node_modules/npm/node_modules -type d -name "benchmark" -print0 | xargs -0 rm -rf --
# README.md LICENSE file permission
find %{buildroot}%{_libdir}/node_modules/npm -name "README.md" -exec chmod -x {} +
find %{buildroot}%{_libdir}/node_modules/npm -name "LICENSE" -exec chmod -x {} +
# browser.js is useless for npm cli
find %{buildroot}%{_libdir}/node_modules/npm -name "browser.js" -delete 

%files
%defattr(-, root, root)
%doc AUTHORS LICENSE *.md
%dir %{_libexecdir}/node_modules
%{_bindir}/node
#%{_prefix}/lib/node_modules
%{_mandir}/man1/node.1.gz
%exclude %{_libdir}/node_modules/npm
%exclude %{_docdir}/%{name}/api

%files npm
%defattr(-, root, root)
%{_bindir}/npm
%dir %{_libdir}/node_modules
%{_libdir}/node_modules/npm
%{_mandir}/man1/npm.1.gz

%files devel
%defattr(-, root, root)
%{_includedir}/node
%{_datadir}/node
%dir %{_datadir}/systemtap
%dir %{_datadir}/systemtap/tapset
%{_datadir}/systemtap/tapset/node.stp

%files docs
%defattr(-,root,root)
%{_docdir}/%{name}/api

%changelog
* Thu Oct 15 2015 Tomas Hrcka <thrcka@redhat.com> - 4.2.1-2
- Rebase to latest LTS release
- Release notes: https://nodejs.org/en/blog/release/v4.2.1/ 

* Thu Oct 15 2015 Tomas Hrcka <thrcka@redhat.com> - 4.1.2-2
- Rebase addon-gypi patch

* Tue Oct 13 2015 Tomas Hrcka <thrcka@redhat.com> - 4.1.2-1
- Update to 4.1.2
- Replace patch3 with upstream fix
* Fri Oct  2 2015 develop7@develop7.info
- replace node-no-fips.patch with upstream fix
* Fri Oct  2 2015 i@marguerite.su
- fix build by using internal openssl for openSUSE <= 1320
  which didn't provide openssl 1.0.2
- install missing addon-rpm.gypi (boo#948045)
* Tue Sep 29 2015 meissner@suse.com
- Do not force enable FIPS mode. bsc#947747
* Sat Sep 12 2015 i@marguerite.su
- update to 4.0.0
  * child_process: ChildProcess.prototype.send() and process.send()
    operate asynchronously across all platforms so an optional
    callback parameter has been introduced that will be invoked once
    the message has been sent.
  * node: Rename "io.js" code to "Node.js".
  * node-gyp: This release bundles an updated version of node-gyp
    that works with all versions of Node.js and io.js including
    nightly and release candidate builds. From io.js v3 and Node.js
    v4 onward, it will only download a headers tarball when building
    addons rather than the entire source.
  * npm: Upgrade to version 2.14.2 from 2.13.3, includes a security
    update.
  * timers: Improved timer performance from porting the 0.12
    implementation, plus minor fixes.
  * util: The util.is*() functions have been deprecated, beginning
    with deprecation warnings in the documentation for this release,
    users are encouraged to seek more robust alternatives in the
    npm registry.
  * v8: Upgrade to version 4.5.103.30 from 4.4.63.30
    + Implement new TypedArray prototype methods: copyWithin(),
    every(), fill(), filter(), find(), findIndex(), forEach(),
    indexOf(), join(), lastIndexOf(), map(), reduce(),
    reduceRight(), reverse(), slice(), some(), sort().
    + Implement new TypedArray.from() and TypedArray.of() functions.
    + Implement arrow functions
- drop nodejs-openssl-missing-api.patch: it's for 0.9.8.
- ppc/ppc64(le) is natively supported since nodejs 3.0.0.
  so drop nodejs-v0.12.7-release-ppc.patch.bz2
- drop node-gcc5.patch, upstream fixed
- add nodejs-lib64path.patch, adjust libdir
- add nodejs-libpath.patch, adjust libdir
- add node-gyp-addon-gypi.patch
  * use custom addon.gypi by default instead of downloading
    node source
- add node_modules clean up codes
* Wed Jul 29 2015 i@marguerite.su
- update version 0.12.7
  * openssl: upgrade to 1.0.1p
  * npm: upgrade to 2.11.3
  * v8: cherry-pick JitCodeEvent patch from upstream
- changes in 0.12.6
  * v8: fix out-of-band write in utf8 decoder
  * fix boo#937414: CVE-2015-5380: nodejs: out of band write
* Sat Jul 25 2015 i@marguerite.su
- build with bundled npm
* Thu Jun 25 2015 i@marguerite.su
- update version 0.12.5
  * openssl: upgrade to 1.0.1o
  * npm: upgrade to 2.11.2
  * uv: upgrade to 1.6.1
  * V8: avoid deadlock when profiling is active
  * install: fix source path for openssl headers
  * install: make sure opensslconf.h is overwritten
  * timers: fix timeout when added in timer's callback
- add patch: node-gcc5.patch
  * fix gcc 5 version detection
* Fri Jun  5 2015 i@marguerite.su
- update version 0.12.4
  * npm: upgrade to 2.10.1
  * V8: revert v8 Array.prototype.values() removal
  * win: bring back xp/2k3 support
- previous changes from 0.12.1 to 0.12.3 see ChangeLog
* Fri Apr  3 2015 dmueller@suse.com
- enable aarch64
- add support-arm64-build.patch
* Thu Mar 19 2015 dmacvicar@suse.de
- enable s390x
* Sun Mar  1 2015 i@marguerite.su
- update version 0.12.0
  * npm: upgrade to 2.5.1
  * mdb_v8: update for v0.12
- drop nodejs-v0.10.32-release-ppc.patch.bz2
- add nodejs-v0.12.0-release-ppc.patch.bz2
- add README.SUSE.PowerPC to explain how to generate ppc patch
* Wed Jan 21 2015 normand@linux.vnet.ibm.com
- Add three arches to ExclusiveArch: ppc ppc64 ppc64le
- Add nodejs-v0.10.32-release-ppc.patch.bz2 for them
  (required as PowerPC support not yet upstream)
  (the patch header details how it is created)
- do not configure --with-gdb for those architectures
* Thu Oct  9 2014 jgleissner@suse.com
- removed macros.nodejs (moved to nodejs-packaging)
* Wed Sep 17 2014 i@marguerite.su
- update version 0.10.32
  * v8: fix a crash introduced by previous release
  * configure: add --openssl-no-asm flag
  * crypto: use domains for any callback-taking method
  * http: do not send `0\r\n\r\n` in TE HEAD responses
  * querystring: fix unescape override
  * url: Add support for RFC 3490 separators
* Wed Sep 10 2014 jgleissner@suse.com
- do not install NPM
- use /usr/lib/node_modules instead of /usr/lib64/node_modules even
  on x86_64 (node modules are not binary)
- drop patch: nodejs-lib64path.patch and nodejs-libpath.patch
  * installing in /usr/lib64 doesn't really make sense for non-binary files
- drop patch: node-gyp-addon-gypi.patch and
  nodejs-add_missing_shebang_to_read-package-json.patch
  * they were patching npm files, which is separate now
* Sat Aug 23 2014 i@marguerite.su
- workaround for sles
* Fri Aug 22 2014 i@marguerite.su
- update version 0.10.31
  * v8: backport CVE-2013-6668
  * openssl: Update to v1.0.1i
  * npm: Update to v1.4.23
  * cluster: disconnect should not be synchronous
  * fs: fix fs.readFileSync fd leak when get RangeError
  * stream: fix Readable.wrap objectMode falsy values
  * timers: fix timers with non-integer delay hanging
* Sat Aug 16 2014 javier@opensuse.org
- Update to version 0.10.30
  * uv: Upgrade to v0.10.28
  * npm: Upgrade to v1.4.21
  * v8: Interrupts must not mask stack overflow.
  * Revert "stream: start old-mode read in a next tick" (Fedor Indutny)
  * buffer: fix sign overflow in `readUIn32BE` (Fedor Indutny)
  * buffer: improve {read,write}{U}Int* methods (Nick Apperson)
  * child_process: handle writeUtf8String error (Fedor Indutny)
  * deps: backport 4ed5fde4f from v8 upstream (Fedor Indutny)
  * deps: cherry-pick eca441b2 from OpenSSL (Fedor Indutny)
  * lib: remove and restructure calls to isNaN() (cjihrig)
  * module: eliminate double `getenv()` (Maciej Małecki)
  * stream2: flush extant data on read of ended stream (Chris Dickinson)
  * streams: remove unused require('assert') (Rod Vagg)
  * timers: backport f8193ab (Julien Gilli)
  * util.h: interface compatibility (Oguz Bastemur)
  * zlib: do not crash on write after close (Fedor Indutny)
* Tue Jul 29 2014 i@marguerite.su
- fix a typo in macros.nodejs
- explicitly use /usr/lib, %%%%{_libexecdir} will resolve to
  /usr/lib64 on sles x86_64 versions.
* Fri Jul 18 2014 i@marguerite.su
- update version 0.10.29
  * openssl: to 1.0.1h (CVE-2014-0224)
  * npm: upgrade to 1.4.10
  * utf8: Prevent Node from sending invalid UTF-8 (Felix Geisendörfer)
  * NOTE* this introduces a breaking change, previously you could construct
    invalid UTF-8 and invoke an error in a client that was expecting valid
    UTF-8, now unmatched surrogate pairs are replaced with the unknown UTF-8
    character. To restore the old functionality simply have NODE_INVALID_UTF8
    environment variable set.
  * child_process: do not set args before throwing (Greg Sabia Tucker)
  * child_process: spawn() does not throw TypeError (Greg Sabia Tucker)
  * constants: export O_NONBLOCK (Fedor Indutny)
  * crypto: improve memory usage (Alexis Campailla)
  * fs: close file if fstat() fails in readFile() (cjihrig)
  * lib: name EventEmitter prototype methods (Ben Noordhuis)
  * tls: fix performance issue (Alexis Campailla)
* Fri Jul 18 2014 i@marguerite.su
- fix changelog chronologically
* Wed May 28 2014 nikolai@prokoschenko.de
- fixes
  * initialization of the next build step was missing in case original node
    headers were to be used in node-gyp
* Fri May  2 2014 i@marguerite.su
- update version 0.10.27
  * npm: upgrade to v1.4.8
  * openssl: upgrade to 1.0.1g
  * uv: update to v0.10.27
  * dns: fix certain txt entries (Fedor Indutny)
  * assert: Ensure reflexivity of deepEqual (Mike Pennisi)
  * child_process: fix deadlock when sending handles (Fedor Indutny)
  * child_process: fix sending handle twice (Fedor Indutny)
  * crypto: do not lowercase cipher/hash names (Fedor Indutny)
  * dtrace: workaround linker bug on FreeBSD (Fedor Indutny)
  * http: do not emit EOF non-readable socket (Fedor Indutny)
  * http: invoke createConnection when no agent (Nathan Rajlich)
  * stream: remove useless check (Brian White)
  * timer: don't reschedule timer bucket in a domain (Greg Brail)
  * url: treat \ the same as / (isaacs)
  * util: format as Error if instanceof Error (Rod Vagg)
- add macros.nodejs
* Sun Apr 27 2014 lars@linux-schulserver.de
- update to 0.10.26:
  * cares: backport TXT parsing fix (Fedor Indutny)
  * child_process: fix spawn() optional arguments (Sam Roberts)
  * child_process: don't assert on stale file descriptor events (Fedor Indutny)
  * cluster: report more errors to workers (Fedor Indutny)
  * cluster, v8: fix --logfile=%%p.log (Ben Noordhuis)
  * crypto: Make Decipher._flush() emit errors. (Kai Groner)
  * crypto: throw on SignFinal failure (Fedor Indutny)
  * crypto: update root certificates (Ben Noordhuis)
  * crypto: clear errors from verify failure (Timothy J Fontaine)
  * debugger: Fix breakpoint not showing after restart (Farid Neshat)
  * debugger: Fix bug in sb() with unnamed script (Maxim Bogushevich)
  * dgram: fix abort when getting `fd` of closed dgram (Fedor Indutny)
  * domains: exit() only affects active domains (Ryan Graham)
  * dtrace: interpret two byte strings (Dave Pacheco)
  * events: do not accept NaN in setMaxListeners (Fedor Indutny)
  * events: avoid calling `once` functions twice (Tim Wood)
  * events: fix TypeError in removeAllListeners (Jeremy Martin)
  * fs: make unwatchFile() insensitive to path (iamdoron)
  * fs: fix fs.truncate() file content zeroing bug (Ben Noordhuis)
  * fs: report correct path when EEXIST (Fedor Indutny)
  * http: provide backpressure for pipeline flood (isaacs)
  * module: only cache package main (Wyatt Preul)
  * net: do not re-emit stream errors (Fedor Indutny)
  * net: make Socket destroy() re-entrance safe (Jun Ma)
  * net: reset `endEmitted` on reconnect (Fedor Indutny)
  * node: do not close stdio implicitly (Fedor Indutny)
  * process: enforce allowed signals for kill (Sam Roberts)
  * readline: handle input starting with control chars (Eric Schrock)
  * repl: do not insert duplicates into completions (Maciej Małecki)
  * src: OnFatalError handler must abort() (Timothy J Fontaine)
  * tls: emit 'end' on .receivedShutdown (Fedor Indutny)
  * tls: fix potential data corruption (Fedor Indutny)
  * tls: handle `ssl.start()` errors appropriately (Fedor Indutny)
  * tls: reset NPN callbacks after SNI (Fedor Indutny)
  * tls: prevent stalls by using read(0) (Fedor Indutny)
  * tls: fix premature connection termination (Ben Noordhuis)
  * tls: fix sporadic hang and partial reads (Fedor Indutny)
  * tls: prevent duplicate values returned from read (Nathan Rajlich)
  * tls: NPN protocols are now local to connections (Fedor Indutny)
  * src: Fix memory leak on closed handles (Timothy J Fontaine)
  * stream: writes may return false but forget to emit drain (Yang Tianyang)
  * stream: objectMode transforms allow falsey values (isaacs)
  * stream: Don't crash on unset _events property (isaacs)
  * stream: Pass 'buffer' encoding with decoded writable chunks (isaacs)
  * v8: support compiling with VS2013 (Fedor Indutny)
  * v8: Fix enumeration for objects with lots of properties
  * v8: backport fix for CVE-2013-6639 and CVE-2013-6640
- refresh nodejs-lib64path.patch
- rebuild node-gyp-addon-gypi.patch from scratch
- small specfile cleanup (remove commented values finally)
- fix two file permissions during setup
* Fri Mar 21 2014 jmassaguerpla@suse.com
- move v8 headers to node subdirectory in include dir. Otherwise
  it conflicts with the v8 package
* Mon Jan 13 2014 nikolai@prokoschenko.de
- fixes
  * included v8 headers in the -devel package
* Fri Aug 30 2013 pascal.bleser@opensuse.org
- update to 0.10.17:
  * uv: Upgrade v0.10.14
  * http_parser: Do not accept PUN/GEM methods as PUT/GET
  * tls: fix assertion when ssl is destroyed at read
  * stream: Throw on 'error' if listeners removed
  * dgram: fix assertion on bad send() arguments
  * readline: pause stdin before turning off terminal raw mode
  * package:
  - remove unneeded files such as Makefiles, tests, ...
  - fix missing shebangs, exec flags
- changes from 0.10.16:
  * v8: back-port fix for CVE-2013-2882
  * npm: Upgrade to 1.3.8
  * crypto: fix assert() on malformed hex input
  * crypto: fix memory leak in randomBytes() error path
  * events: fix memory leak, don't leak event names
  * http: Handle hex/base64 encodings properly
  * http: improve chunked res.write(buf) performance
  * stream: Fix double pipe error emit
- changes from 0.10.15:
  * src: fix process.getuid() return value
- changes from 0.10.14:
  * os: Don't report negative times in cpu info
  * fs: Handle large UID and GID
  * url: Fix edge-case when protocol is non-lowercase
  * node: call MakeDomainCallback in all domain cases
  * crypto: fix memory leak in LoadPKCS12
- changes from 0.10.13:
  * tls: only wait for finish if we haven't seen it
  * http: Dump response when request is aborted
  * http: use an unref'd timer to fix delay in exit
  * zlib: level can be negative
  * zlib: allow zero values for level and strategy
  * string_bytes: properly detect 64bit
  * src: fix memory leak in UsingDomains
- changes from 0.10.12:
  * readline: make `ctrl + L` clear the screen
  * v8: add setVariableValue debugger command
  * net: Do not destroy socket mid-write
- changes from 0.10.11:
  * v8: fix pointer arithmetic undefined behavior
  * crypto: fix utf8/utf-8 encoding check
  * net: Fix busy loop on POLLERR|POLLHUP on older linux kernels
- changes from 0.10.10:
  * url: Properly parse certain oddly formed urls
  * stream: unshift('') is a noop
- changes from 0.10.9:
  * repl: fix JSON.parse error check
  * tls: proper .destroySoon
  * tls: invoke write cb only after opposite read end
  * tls: ignore .shutdown() syscall error
- changes from 0.10.8:
  * v8: update to 3.14.5.9
  * http: remove bodyHead from 'upgrade' events
  * http: Return true on empty writes, not false
  * http: save roundtrips, convert buffers to strings
  * buffer: throw when writing beyond buffer
  * crypto: Clear error after DiffieHellman key errors
  * string_bytes: strip padding from base64 strings
- changes from 0.10.7:
  * crypto: Don't ignore verify encoding argument
  * buffer, crypto: fix default encoding regression
  * timers: fix setInterval() assert
- changes from 0.10.6:
  * module: Deprecate require.extensions
  * stream: make Readable.wrap support objectMode, empty streams
  * child_process: fix handle delivery
  * crypto: Fix performance regression
* Fri Aug 16 2013 froh@suse.com
- make nodejs use the v8 shipped with it by upstream.
  The API of the new v8 deviates too much and we're not involved
  enough upstream to justify a deviation here.
* Thu Apr 25 2013 adaugherity@tamu.edu
- update to 0.10.5
* Thu Apr 25 2013 adaugherity@tamu.edu
- rebase 0.10.4 build/patches against current OBS state
* Sun Apr 21 2013 dmueller@suse.com
- always runtime require the exact v8 version that was used
  for building, as it breaks binary compatibility quite often
* Sun Apr 21 2013 edy.burt@gmail.com
- updated to 0.8.23
- added nodejs-openssl-missing-api.patch:
  * provides a macro implementation of EVP_PKEY_id, not present
    in openssl 0.9.8j and previous versions.
  * required when building for SLE11, which has older openssl.
- added nodejs-v8-deprecated-api.patch:
  * allows 0.8 versions of nodejs to use newer v8 versions, which
    deprecated (or renamed, in this case) some methods (in 3.15.3)
    and subsequently removed them (in 3.16.5).
* Fri Apr 19 2013 adaugherity@tamu.edu
- make v8 version deps explicit, and add more provides (copied from Fedora)
  This will require manually updating the nodejs pkg whenever there's a
  minor version bump in v8 (3.x to 3.y, not micro, i.e. 3.x.a to 3.x.b),
  but that's better than v8 updates breaking existing nodejs installations.
* Thu Apr 18 2013 adaugherity@tamu.edu
- Fix build on platforms w/openssl 0.9.8 (e.g. SLES 11).
- Fix -devel subpkg -- manually install headers (copied from Fedora),
  and move dtrace and share to -devel subpkg.
  + NodeJS <= 0.8 installed headers itself, so this was not previously
    necessary.
  + NB: Fedora uses an external libuv pkg, but we don't, so we must
    also copy libuv headers.
* Thu Apr 18 2013 dimstar@opensuse.org
- Update to version 0.10.4:
  + See https://raw.github.com/joyent/node/v0.10.4/ChangeLog
- Delete no longer needed patches:
  + node-v0.8.12_missing_include.patch
  + nodejs-devel-lib64path.patch
  + nodejs-no-v8-headers.patch
- Rebase nodejs-lib64path.patch and nodejs-libpath.patch.
- Add nodejs-v8-3.18.0.patch: make node.js compatible to V8 3.18.0.
* Thu Mar  7 2013 dvaleev@suse.com
- Set ExclusiveArch to x86 and ARM
  nodejs depends on v8 which is available only for those arches atm
* Thu Jan 31 2013 adaugherity@tamu.edu
- fix node-gyp to use the system v8 headers instead of those bundled with nodejs
  * Without this, dependencies installed via npm will be built against
    the bundled v8 (3.11.10) but linked against the system libv8 (currently
    3.16.x) which has ABI incompatibilites, and fail to run with symbol
    errors.
  * 3.16 ABI change: http://upstream-tracker.org/compat_reports/v8/3.15.11.7_to_3.16.0/abi_compat_report.html
  * node-gyp patch taken from Fedora SRPM -- https://bugzilla.redhat.com/show_bug.cgi?id=891175#c7
- remove bundled sources for shared dependencies, a la the Fedora 18
  updates-testing package (but simplified a bit)
  * without doing this, /usr/include/node will still have the 3.11.0
    v8 headers, and node-gyp will remain broken
- patch tools/install.py to not install these removed headers
* Fri Nov  2 2012 mrueckert@suse.de
- added node-v0.8.12_missing_include.patch:
  fixes a compiler warning about implicite declaration due to
  missing include.
- enabled usage of system zlib and openssl
- enabled gdb support
- set CFLAGS/CXXFLAGS so the binary gets compiled with the optflags
* Thu Oct 25 2012 douglarek@outlook.com
- update to version 0.8.12
  * npm: Upgrade to 1.1.63
  * crypto: Reduce stability index to 2-Unstable (isaacs)
  * windows: fix handle leak in uv_fs_utime (Bert Belder)
  * windows: fix application crashed popup in debug version (Bert Belder)
  * buffer: report proper retained size in profiler (Ben Noordhuis)
  * buffer: fix byteLength with UTF-16LE (koichik)
  * repl: make "end of input" JSON.parse() errors throw in the REPL (Nathan Rajlich)
  * repl: make invalid RegExp modifiers throw in the REPL (Nathan Rajlich)
  * http: handle multiple Proxy-Authenticate values (Willi Eggeling)
* Mon Sep 17 2012 coolo@suse.com
- update to version 0.8.9
  * v8: upgrade to 3.11.10.22
  * GYP: upgrade to r1477
  * npm: Upgrade to 1.1.61
  * npm: Don't create world-writable files (isaacs)
  * unix: fix memory leak in udp (Ben Noordhuis)
  * unix: map errno ESPIPE (Ben Noordhuis)
  * unix, windows: fix memory corruption in fs-poll.c (Ben Noordhuis)
  * child process: fix processes with IPC channel don't emit 'close' (Bert Belder)
  * build: fix openssl configuration for "arm" builds (Nathan Rajlich)
  * tls: support unix domain socket/named pipe in tls.connect (Shigeki Ohtsu)
  * https: make https.get() accept a URL (koichik)
  * http: respect HTTP/1.0 TE header (Ben Noordhuis)
  * crypto, tls: Domainify setSNICallback, pbkdf2, randomBytes (Ben Noordhuis)
  * stream.pipe: Don't call destroy() unless it's a function (isaacs)
  * unix, windows: fix memory corruption in fs-poll.c (Ben Noordhuis)
  * unix: fix integer overflow in uv_hrtime (Tim Holy)
  * tls: update default cipher list (Ben Noordhuis)
  * unix: Fix llvm and older gcc duplicate symbol warnings (Bert Belder)
  * fs: fix use after free in stat watcher (Ben Noordhuis)
  * crypto: fix uninitialized memory access in openssl (Ben Noordhuis)
  * buffer, crypto: fix buffer decoding (Ben Noordhuis)
  * tls: handle multiple CN fields when verifying cert (Ben Noordhuis)
  * doc: remove unused util from child_process (Kyle Robinson Young)
* Thu Jul 19 2012 jzheng@suse.com
- update to version 0.8.2:
  API changes between v0.6 and v0.8:
  https://github.com/joyent/node/wiki/API-changes-between-v0.6-and-v0.8
- update npm to 1.1.36
- remove node-segfault.patch, as 0.8.2 already has this fix
- remove nodejs-npm-lib64path.patch as no wscript any more
- remove libdir from configure as no such option in 0.8
- update nodejs-lib64path.patch to fix lib64 issue in x86_64
* Fri Jun 15 2012 dvaleev@suse.com
- fix segfault
* Fri Jun 15 2012 dvaleev@suse.com
- update to version 0.6.19
  npm: upgrade to 1.1.24
  fs: no end emit after createReadStream.pause() (Andreas Madsen)
  vm: cleanup module memory leakage (Marcel Laverdet)
  unix: fix loop starvation under high network load (Ben Noordhuis)
  unix: remove abort() in ev_unref() (Ben Noordhuis)
  windows/tty: never report error after forcibly aborting line-buffered read (Bert Belder)
  windows: skip GetFileAttributes call when opening a file (Bert Belder)
* Tue May  8 2012 cthiel@suse.com
- update to version 0.6.17
  * Upgrade npm to 1.1.21
  * uv: Add support for EROFS errors
  * uv: Add support for EIO and ENOSPC errors
  * windows: Add support for EXDEV errors
  * http: Fix client memory leaks
  * fs: fix file descriptor leak in sync functions
  * fs: fix ReadStream / WriteStream double close bug
- changes in version 0.6.16
  * Upgrade V8 to 3.6.6.25
  * Upgrade npm to 1.1.19
  * Windows: add mappings for UV_ENOENT
  * linux: add IN_MOVE_SELF to inotify event mask
  * unix: call pipe handle connection cb on accept() error
  * unix: handle EWOULDBLOCK
  * map EWOULDBLOCK to UV_EAGAIN
  * Map ENOMEM to UV_ENOMEM
  * Child process: support the `gid` and `uid` options
  * test: cluster: add worker death event test
  * typo in node_http_parser
  * http_parser: Eat CRLF between requests, even on connection:close.
  * don't check return value of unsetenv
* Wed Apr 18 2012 saschpe@suse.de
- Update to version 0.6.15:
  * Update npm to 1.1.16
  * Show licenses in binary installers.
  * unix: add uv_fs_read64, uv_fs_write64 and uv_fs_ftruncate64
  * add 64bit offset fs functions
  * fs.readFile: don't make the callback before the fd is closed
  * Fix #2061: segmentation fault on OS X due to stat size mismatch
- Remove empty %%clean section not cleaning up anything (and there's good default)
- Add spec file license header
- Ran spec-cleaner
* Thu Apr  5 2012 cthiel@suse.com
- update to 0.6.14
  see https://github.com/joyent/node/blob/v0.6.14-release/ChangeLog for details
* Wed Feb 15 2012 tuukka.pasanen@ilmi.fi
- Removed doc patch because it's included in neew 0.6.10 nodejs
- Upgraded to newest 0.6.10
- Testing on openSUSE 12.1
* Fri Jan 27 2012 jmassaguerpla@suse.com
- Update to 0.6.8
* Thu Dec  1 2011 jmassaguerpla@suse.com
- Added patch for npm docs
* Wed Nov 30 2011 jmassaguerpla@suse.com
- Fix files section:
  use %%{_libdir} instead of lib64
* Tue Nov 29 2011 jmassaguerpla@suse.com
- Removed 0.6.2 source
* Fri Nov 25 2011 jmassaguerpla@suse.com
- Updated to 0.6.3
    [#2083] Land NPM in Node. It is included in packages/installers and installed on `make install`.
    [#2076] Add logos to windows installer.
    [#1711] Correctly handle http requests without headers. (Ben Noordhuis, Felix Geisendörfer)
    TLS: expose more openssl SSL context options and constants. (Ben Noordhuis)
    [#2177] Windows: don’t kill UDP socket when a packet fails to reach its destination. (Bert Belder)
    Windows: support paths longer than 260 characters. (Igor Zinkovsky)
    Windows: correctly resolve drive-relative paths. (Bert Belder)
    [#2166] Don’t leave file descriptor open after lchmod. (Isaac Schlueter)
    [#2084] Add OS X .pkg build script to make file.
    [#2160] Documentation improvements. (Ben Noordhuis)
* Wed Nov 23 2011 jmassaguerpla@suse.com
- Updated to 0.6.2
- Build and link against system v8
* Tue Oct  4 2011 fcastelli@suse.com
- Revert to latest stable version of node (0.4.12). Some packages didn't work
  properly with unstable.
* Tue Oct  4 2011 fcastelli@suse.com
- Update to latest unstable version of node: 0.5.8
- Build & link against system v8
* Fri Sep 23 2011 fcastelli@suse.com
- The devel package now requires gcc-c++ since most of the native nodejs
  packages need it.
* Thu Sep 22 2011 fcastelli@suse.com
- small cleanup inside of spec file
